@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2008 Emweb bvba, Kessel-Lo, Belgium.
+ * Copyright (C) 2008 Emweb bv, Herent, Belgium.
  *
  * See the LICENSE file for terms of use.
  */
@@ -181,7 +181,7 @@ public:
 #ifndef WT_TARGET_JAVA
   typedef std::map<ItemDataRole, cpp17::any> DataMap;
 #else
-  typedef std::treemap<int, cpp17::any> DataMap;
+  typedef std::treemap<ItemDataRole, cpp17::any> DataMap;
 #endif
 
   /*! \brief Creates a new data model.
@@ -478,7 +478,7 @@ public:
   /*! \brief Expands a column.
    *
    * Expands a column. This may only be called by a view when the
-   * Wt::MatchFlag::ColumnIsCollapsed flag is set.
+   * Wt::HeaderFlag::ColumnIsCollapsed flag is set.
    *
    * The default implementation does nothing.
    *
@@ -489,7 +489,7 @@ public:
   /*! \brief Collapses a column.
    *
    * Collapses a column. This may only be called by a view when the
-   * Wt::MatchFlag::ColumnIsExpandedLeft or Wt::MatchFlag::ColumnIsExpandedRight flag is set.
+   * Wt::HeaderFlag::ColumnIsExpandedLeft or Wt::HeaderFlag::ColumnIsExpandedRight flag is set.
    *
    * The default implementation does nothing.
    *
