@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2008 Emweb bvba, Kessel-Lo, Belgium.
+ * Copyright (C) 2008 Emweb bv, Herent, Belgium.
  *
  * See the LICENSE file for terms of use.
  */
@@ -107,6 +107,8 @@ public:
    */
   WBoxLayout(LayoutDirection dir);
 
+  virtual ~WBoxLayout() override;
+
   virtual void addItem(std::unique_ptr<WLayoutItem> item) override;
   virtual std::unique_ptr<WLayoutItem> removeItem(WLayoutItem *item) override;
   virtual WLayoutItem *itemAt(int index) const override;
@@ -185,6 +187,11 @@ public:
     addWidget(std::unique_ptr<WWidget>(std::move(widget)), stretch, alignment);
     return result;
   }
+#else // WT_TARGET_JAVA
+  template <typename Widget>
+    Widget *addWidget(std::unique_ptr<Widget> widget);
+  template <typename Widget>
+    Widget *addWidget(std::unique_ptr<Widget> widget, int stretch);
 #endif // WT_TARGET_JAVA
 
   /*! \brief Adds a nested layout to the layout.
@@ -193,9 +200,15 @@ public:
    *
    * \sa addWidget(WWidget *, int, WFlags<AlignmentFlag>), insertLayout()
    */
+#ifndef WT_TARGET_JAVA
   void addLayout(std::unique_ptr<WLayout> layout, int stretch,
                  WFlags<AlignmentFlag> alignment);
+#else // WT_TARGET_JAVA
+  void addLayout(std::unique_ptr<WLayout> layout, int stretch = 0,
+                 WFlags<AlignmentFlag> alignment = None);
+#endif // WT_TARGET_JAVA
 
+#ifndef WT_TARGET_JAVA
   /*! \briefs Adds a nested layout to the layout, returning a raw pointer.
    *
    * This is implemented as:
@@ -206,7 +219,6 @@ public:
    * return result;
    * \endcode
    */
-#ifndef WT_TARGET_JAVA
   template <typename Layout>
     Layout *addLayout(std::unique_ptr<Layout> layout, int stretch = 0,
                       WFlags<AlignmentFlag> alignment = None)
@@ -215,11 +227,6 @@ public:
     addLayout(std::unique_ptr<WLayout>(std::move(layout)), stretch, alignment);
     return result;
   }
-#else // WT_TARGET_JAVA
-  template <typename Layout>
-    Layout *addLayout(std::unique_ptr<Layout> layout);
-  template <typename Layout>
-    Layout *addLayout(std::unique_ptr<Layout> layout, int stretch);
 #endif // WT_TARGET_JAVA
 
   /*! \brief Adds extra spacing.
@@ -376,6 +383,7 @@ public:
   bool isResizable(int index) const;
 
   virtual void iterateWidgets(const HandleWidgetMethod& method) const override;
+  virtual bool implementationIsFlexLayout() const override;
 
 protected:
   void insertItem(int index, std::unique_ptr<WLayoutItem> item, int stretch,
@@ -393,7 +401,6 @@ private:
   virtual void setParentWidget(WWidget *parent) override;
 
   void setImplementation();
-  bool implementationIsFlexLayout() const;
 };
 
 }
