@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2008 Emweb bvba, Kessel-Lo, Belgium.
+ * Copyright (C) 2008 Emweb bv, Herent, Belgium.
  *
  * See the LICENSE file for terms of use.
  */
@@ -13,8 +13,12 @@
 #include <Wt/Http/Request.h>
 
 #include <cassert>
-#include <vector>
 #include <map>
+#include <vector>
+
+#ifndef WT_TARGET_JAVA
+#include <type_traits>
+#endif // WT_TARGET_JAVA
 
 namespace Wt {
 
@@ -63,12 +67,6 @@ class WStatelessSlot;
  * \endcode
  * As the example illustrates, slots are ordinary %WObject methods.
  *
- * A second feature of %WObject is that they allow ownership
- * organization in ownership object trees. When an object is created
- * with another object as parent, it's ownership is transferred to the
- * parent. The child object will be deleted together with the
- * parent, unless they are removed first, in which owernship is released.
- *
  * In conjunction with EventSignal, %WObject also facilitates learning
  * of client-side event handling (in JavaScript) through invocation of
  * the slot method. This is only possible when the slot behaviour is
@@ -92,6 +90,7 @@ public:
 
   virtual ~WObject();  
 
+#ifndef WT_TARGET_JAVA
   /*! \brief Add a child WObject whose lifetime is determined by this WObject
    */
   void addChild(std::unique_ptr<WObject> child);
@@ -118,6 +117,29 @@ public:
    */
   std::unique_ptr<WObject> removeChild(WObject *child);
 
+  /*! \brief Remove a child WObject, so its lifetime is no longer determined by this WObject
+   *
+   * This is an overload that automatically casts the returned value to a unique_ptr<Child> for convenience
+   *
+   * This is implemented as:
+   * \code
+   * return std::unique_ptr<Child>(static_cast<Child*>(removeChild(static_cast<WObject*>(child)).release()));
+   * \endcode
+   */
+  template <typename Child>
+#ifdef DOXYGEN_ONLY
+  std::unique_ptr<Child> removeChild(Child *child)
+#else // DOXYGEN_ONLY
+  typename std::enable_if<std::is_convertible<Child*,WObject*>::value && !std::is_same<Child,WObject>::value, std::unique_ptr<Child>>::type removeChild(Child *child)
+#endif // DOXYGEN_ONLY
+  {
+    std::unique_ptr<WObject> result = removeChild(static_cast<WObject*>(child));
+    // The result is null or the given child, guaranteeing that result.release() can be casted to Child*
+    assert(result == nullptr || result.get() == child);
+    return std::unique_ptr<Child>(static_cast<Child*>(result.release()));
+  }
+#endif // WT_TARGET_JAVA
+
   /*
    * Unique id's
    */
@@ -317,6 +339,7 @@ private:
   static unsigned nextObjId_;
 
   friend class EventSignalBase;
+  friend class WApplication;
   friend class WebSession;
 };
 
